@@ -30,7 +30,7 @@
 #include <KoDocument.h>
 #include <KWView.h>
 #include <styles/KoListStyle.h>
-#include <KoPAView.h>
+
 
 #include "Splash.h"
 #include "PreviewDialog.h"
@@ -43,9 +43,17 @@
 #include "FoCellTool.h"
 #include "VirtualKeyBoard.h"
 #include "FoCellToolFactory.h"
+#include "DigitalSignatureDialog.h"
 
+#include <KoPAView.h>
+#include <KoPACanvas.h>
+#include <KoTextShapeData.h>
+#include <KoTextDocument.h>
+#include <KoShapeFactoryBase.h>
+#include <KoShapeRegistry.h>
 
 #ifdef Q_WS_MAEMO_5
+#include "FoDocumentRdf.h"
 #include "Accelerator.h"
 #endif
 
@@ -121,6 +129,8 @@ protected:
 private:
     Ui::MainWindow *m_ui;
     FoCellToolFactory *m_cellToolFactory;
+
+
     
 ///////////////////////////
 // Collaborative editing //
@@ -155,13 +165,30 @@ private slots:
 /////////////////////////////
 /////////////////////////////
 
+    //presentation editing
+    private:
+        QTextDocument *document;
+        QPointer<KoTextEditor> m_pEditor;
+        KoShape *m_textShape;
+        KoShape *currentShapeSelected;
+        KoTextShapeData *currentSelectedTextShapeData;
+        QTextDocument *documentForCurrentShape;
+
+        KoPAView *m_kopaview;
+    private slots:
+        void insertNewTextShape();
+        void insertNewTable();
+//        void deleteSelection();
+
+
+    ////
 
 /////virtualkeyboard
 
 private:
 
     QShortcut *shortcutForVirtualKeyBoard;
-    QShortcut *spaceHandlerShortcutForVirtualKeyBoard;
+//    QShortcut *spaceHandlerShortcutForVirtualKeyBoard;
     static bool virtualKeyBoardIsOnScreen;
 
 
@@ -241,11 +268,7 @@ friend void AcceleratorScrollSlide::ifNoScroll();
 ////////////////////////////////
 
 private:
-    /*!
-      * Stores the URL of the open file
-      */
-    KUrl m_url;
-    /*!
+   /*!
       * Holds the properties of presentation style and time
       */
     int gl_showtime;
@@ -310,7 +333,6 @@ private:
     QLabel * m_templatepreview;
     QStringList m_temptitle;
     QStringList m_templatepath;
-    int m_tempnumber;
     QString newpresenter;
     /*!
      * Confirmation dialog for closing new document
@@ -460,7 +482,7 @@ private:
 
     void init();
     /*!
-     * close the document if it is open and reinit to NULL
+     * close the document if it is open and reinit to 0
      */
     void closeDocument();
     /*!
@@ -472,9 +494,9 @@ private:
      */
     void openNewDocument(DocumentType);
     /*!
-     *Applies appropiate file extension during saving operation
+     *Retrieves path for saving file
      */
-    QString getFileExtension(DocumentType);
+    QString getFileSavePath(DocumentType);
     /*!
      *Function to add formatframe components
      */
@@ -648,11 +670,13 @@ private slots:
     /*!
      * Slot to actionEdit toggled signal
      */
-    void editToolBar(bool);
+    void editToolBar(bool status=true);
     /*!
      * Slot to actionClose signal
+     * @parm isWindowClosed set to true if you are calling it from the window
+     *       close event.
      */
-    void closeDoc();
+    void closeDoc(bool isWindowClosed=false);
     /*!
      *  Slot to convert character into bold
      */
@@ -846,13 +870,12 @@ private slots:
      * Slot for progress indicator
      */
     //void slotProgress(int value);
-
-    void inserNewSlide();
-public slots:
     /*!
-     * Slot to perform save operation
+     * Slot to show digital signature information
      */
-    void saveFile();
+    void showDigitalSignatureInfo();
+
+public slots:
     /*!
      * Slot to perform save as operation
      */
@@ -861,7 +884,7 @@ public slots:
      * Slot to  dialog fileSelected signal
      * /param filename
      */
-    void openDocument(const QString &fileName);
+    void openDocument(const QString &fileName, bool isNewDocument=false);
     /*!
      * Slot to choose new document
      */
@@ -906,10 +929,6 @@ private:
     QMap<QString, OfficeInterface*> loadedPlugins;
 
     void setShowProgressIndicator(bool visible);
-    /*!
-     * true if new document is open
-     */
-    bool m_newDocOpen;
     /*!
      * true if document is modified
      */
@@ -983,6 +1002,14 @@ private:
      * Tool bar for spread sheet.
      */
     QToolBar *m_spreadEditToolBar;
+
+    DigitalSignatureDialog *digitalSignatureDialog;
+
+#ifdef Q_WS_MAEMO_5
+    FoDocumentRdf *foDocumentRdf;
+
+    QShortcut *rdfShortcut;
+#endif
 signals:
     /*!
      * Presentation has entered full screen mode.
@@ -1000,6 +1027,25 @@ signals:
      * Presentation has moved to the previous slide.
      */
     void previousSlide();
+
+ public slots:
+    /*!
+     * Enable the select tool. This will allow shapes to be selected and moved around
+     */
+    void enableSelectTool();
+    /*!
+     * Insert picture into the document
+     */
+    void insertImage();
+    /*!
+     * Shows available items which can be inserted into the document
+     */
+    void insertButtonClicked();
+    /*!
+     * Show cut,copy, paste actions
+     */
+    void showCCP();
+
 };
 
 #endif // MAINWINDOW_H
